@@ -1,10 +1,13 @@
 import types
+import logging
 
 from PyQt5.Qt import QObject
 
 import pqaut.automator.factory as factory
 
 
+logger = logging.getLogger(__name__)
+
 class QObjectAutomator(object):
 
     def __init__(self, target):
@@ -14,9 +17,6 @@ class QObjectAutomator(object):
     def target(self):
         return self._target
 
-    def clickable_target(self, point):
-        return self._target
-
     def click(self):
         pass
 
@@ -29,8 +29,9 @@ class QObjectAutomator(object):
         try:
             children = self._target.findChildren(QObject)
         except Exception as ex:
-            print ex
+            logger.debug('could not find children on {}: {}'.format(self._target, ex))
 
+        logger.debug('found children {} on {}'.format(self._target, children))
         return [factory.automate(c) for c in children];
 
     def is_match(self, value, automation_type=None):
