@@ -1,12 +1,10 @@
 import os
+import logging
 
 from PyQt5.Qt import QObject, QWidget, QPoint, QPointF, QTest, Qt, pyqtSignal
 
 
-def log(message):
-    if "DEBUG" in os.environ:
-        print("[pqaut] {0}".format(message))
-        print("")
+logger = logging.getLogger(__name__)
 
 class Clicker(QObject):
     do_click = pyqtSignal(QObject, QPoint)
@@ -16,12 +14,12 @@ class Clicker(QObject):
         self.do_click.connect(self._click_on_ui_thread, type=Qt.BlockingQueuedConnection)
 
     def click_on(self, target, point = QPoint(0,0)):
-        log("Clicking {} at {},{}".format(target, point.x(), point.y()))
+        logger.debug("clicking {} at {},{}".format(target, point.x(), point.y()))
         self.do_click.emit(target, point)
 
     def _click_on_ui_thread(self, widget, point):
         try:
             QTest.mouseClick(widget, Qt.LeftButton, Qt.NoModifier, point)
-            log("Successfully clicked {} from UI thread".format(widget))
+            logger.debug("successfully clicked {} from UI thread".format(widget))
         except Exception as error:
-            log("Error happened while trying to click {} from UI thread: {}".format(widget, error))
+            logger.error("error happened while trying to click {} from UI thread: {}".format(widget, error))
